@@ -1,24 +1,26 @@
-"""Provide strategies for given endpoint(s) definition."""
+"""High-level API for creating Hypothesis tests."""
 import asyncio
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 import hypothesis
+from hypothesis import Phase
 from hypothesis import strategies as st
+from hypothesis.errors import Unsatisfiable
 from hypothesis.strategies import SearchStrategy
 from hypothesis.utils.conventions import InferType
+from hypothesis_jsonschema._canonicalise import HypothesisRefResolutionError
 
 from .constants import DEFAULT_DEADLINE, DataGenerationMethod
 from .exceptions import InvalidSchema
 from .hooks import GLOBAL_HOOK_DISPATCHER, HookContext, HookDispatcher
-from .models import Case, Endpoint
-from .stateful import Feedback, Stateful
+from .models import APIOperation, Case
 
 GivenInput = Union[SearchStrategy, InferType]
 
 
 def create_test(
     *,
-    endpoint: Endpoint,
+    operation: APIOperation,
     test: Callable,
     settings: Optional[hypothesis.settings] = None,
     seed: Optional[int] = None,
@@ -28,14 +30,7 @@ def create_test(
 ) -> Callable:
     """Create a Hypothesis test."""
     hook_dispatcher = getattr(test, "_schemathesis_hooks", None)
-    feedback: Optional[Feedback]
-    if endpoint.schema.stateful == Stateful.links:
-        feedback = Feedback(endpoint.schema.stateful, endpoint)
-    else:
-        feedback = None
-    strategy = endpoint.as_strategy(
-        hooks=hook_dispatcher, feedback=feedback, data_generation_method=data_generation_method
-    )
+    strategy = operation.as_strategy(hooks=hook_dispatcher, data_generation_method=data_generation_method)
     _given_kwargs = (_given_kwargs or {}).copy()
     _given_kwargs.setdefault("case", strategy)
     wrapped_test = hypothesis.given(*_given_args, **_given_kwargs)(test)
@@ -46,8 +41,10 @@ def create_test(
     setup_default_deadline(wrapped_test)
     if settings is not None:
         wrapped_test = settings(wrapped_test)
-    wrapped_test._schemathesis_feedback = feedback  # type: ignore
-    return add_examples(wrapped_test, endpoint, hook_dispatcher=hook_dispatcher)
+    existing_settings = getattr(wrapped_test, "_hypothesis_internal_use_settings", None)
+    if existing_settings and Phase.explicit in existing_settings.phases:
+        wrapped_test = add_examples(wrapped_test, operation, hook_dispatcher=hook_dispatcher)
+    return wrapped_test
 
 
 def setup_default_deadline(wrapped_test: Callable) -> None:
@@ -59,21 +56,6 @@ def setup_default_deadline(wrapped_test: Callable) -> None:
         wrapped_test._hypothesis_internal_use_settings = new_settings  # type: ignore
 
 
-def make_test_or_exception(
-    endpoint: Endpoint,
-    func: Callable,
-    settings: Optional[hypothesis.settings] = None,
-    seed: Optional[int] = None,
-    data_generation_method: DataGenerationMethod = DataGenerationMethod.default(),
-) -> Union[Callable, InvalidSchema]:
-    try:
-        return create_test(
-            endpoint=endpoint, test=func, settings=settings, seed=seed, data_generation_method=data_generation_method
-        )
-    except InvalidSchema as exc:
-        return exc
-
-
 def make_async_test(test: Callable) -> Callable:
     def async_run(*args: Any, **kwargs: Any) -> None:
         loop = asyncio.get_event_loop()
@@ -84,12 +66,23 @@ def make_async_test(test: Callable) -> Callable:
     return async_run
 
 
-def add_examples(test: Callable, endpoint: Endpoint, hook_dispatcher: Optional[HookDispatcher] = None) -> Callable:
+def add_examples(test: Callable, operation: APIOperation, hook_dispatcher: Optional[HookDispatcher] = None) -> Callable:
     """Add examples to the Hypothesis test, if they are specified in the schema."""
-    examples: List[Case] = [get_single_example(strategy) for strategy in endpoint.get_strategies_from_examples()]
-    context = HookContext(endpoint)  # context should be passed here instead
+    try:
+        examples: List[Case] = [get_single_example(strategy) for strategy in operation.get_strategies_from_examples()]
+    except (InvalidSchema, HypothesisRefResolutionError, Unsatisfiable):
+        # Invalid schema:
+        # In this case, the user didn't pass `--validate-schema=false` and see an error in the output anyway,
+        # and no tests will be executed. For this reason, examples can be skipped
+        # Recursive references: This test will be skipped anyway
+        # Unsatisfiable:
+        # The underlying schema is not satisfiable and test will raise an error for the same reason.
+        # Skipping this exception here allows us to continue the testing process for other operations.
+        # Still, we allow to run user-defined hooks
+        examples = []
+    context = HookContext(operation)  # context should be passed here instead
     GLOBAL_HOOK_DISPATCHER.dispatch("before_add_examples", context, examples)
-    endpoint.schema.hooks.dispatch("before_add_examples", context, examples)
+    operation.schema.hooks.dispatch("before_add_examples", context, examples)
     if hook_dispatcher:
         hook_dispatcher.dispatch("before_add_examples", context, examples)
     for example in examples:
