@@ -10,7 +10,7 @@ from ..._compat import metadata
 from ...constants import __version__
 from ...models import Status
 from ...runner import events
-from ...runner.serialization import SerializedCase, SerializedTestResult
+from ...runner.serialization import SerializedCase, SerializedError, SerializedTestResult
 from ..context import ExecutionContext
 from ..handlers import EventHandler, get_unique_failures
 
@@ -55,20 +55,19 @@ def display_execution_result(context: ExecutionContext, event: events.AfterExecu
 
 def display_percentage(context: ExecutionContext, event: events.AfterExecution) -> None:
     """Add the current progress in % to the right side of the current line."""
-    padding = 1
-    endpoints_count = cast(int, context.endpoints_count)  # is already initialized via `Initialized` event
-    current_percentage = get_percentage(context.endpoints_processed, endpoints_count)
+    operations_count = cast(int, context.operations_count)  # is already initialized via `Initialized` event
+    current_percentage = get_percentage(context.operations_processed, operations_count)
     styled = click.style(current_percentage, fg="cyan")
-    # Total length of the message, so it will fill to the right border of the terminal minus padding
-    length = get_terminal_width() - context.current_line_length + len(styled) - len(current_percentage) - padding
+    # Total length of the message, so it will fill to the right border of the terminal.
+    # Padding is already taken into account in `context.current_line_length`
+    length = get_terminal_width() - context.current_line_length + len(styled) - len(current_percentage)
     template = f"{{:>{length}}}"
     click.echo(template.format(styled))
 
 
 def display_summary(event: events.Finished) -> None:
-    message, color, status_code = get_summary_output(event)
+    message, color = get_summary_output(event)
     display_section_name(message, fg=color)
-    raise click.exceptions.Exit(status_code)
 
 
 def get_summary_message_parts(event: events.Finished) -> List[str]:
@@ -85,21 +84,18 @@ def get_summary_message_parts(event: events.Finished) -> List[str]:
     return parts
 
 
-def get_summary_output(event: events.Finished) -> Tuple[str, str, int]:
+def get_summary_output(event: events.Finished) -> Tuple[str, str]:
     parts = get_summary_message_parts(event)
     if not parts:
         message = "Empty test suite"
         color = "yellow"
-        status_code = 0
     else:
         message = f'{", ".join(parts)} in {event.running_time:.2f}s'
         if event.has_failures or event.has_errors:
             color = "red"
-            status_code = 1
         else:
             color = "green"
-            status_code = 0
-    return message, color, status_code
+    return message, color
 
 
 def display_hypothesis_output(hypothesis_output: List[str]) -> None:
@@ -120,6 +116,8 @@ def display_errors(context: ExecutionContext, event: events.Finished) -> None:
         if not result.has_errors:
             continue
         display_single_error(context, result)
+    if event.generic_errors:
+        display_generic_errors(context, event.generic_errors)
     if not context.show_errors_tracebacks:
         click.secho(
             "Add this option to your command line parameters to see full tracebacks: --show-errors-tracebacks", fg="red"
@@ -129,15 +127,25 @@ def display_errors(context: ExecutionContext, event: events.Finished) -> None:
 def display_single_error(context: ExecutionContext, result: SerializedTestResult) -> None:
     display_subsection(result)
     for error in result.errors:
-        if context.show_errors_tracebacks:
-            message = error.exception_with_traceback
-        else:
-            message = error.exception
-        if error.exception.startswith("schemathesis.exceptions.InvalidSchema"):
-            message += DISABLE_SCHEMA_VALIDATION_MESSAGE + "\n"
-        click.secho(message, fg="red")
-        if error.example is not None:
-            display_example(context, error.example, seed=result.seed)
+        _display_error(context, error, result.seed)
+
+
+def display_generic_errors(context: ExecutionContext, errors: List[SerializedError]) -> None:
+    for error in errors:
+        display_section_name(error.title or "Generic error", "_", fg="red")
+        _display_error(context, error)
+
+
+def _display_error(context: ExecutionContext, error: SerializedError, seed: Optional[int] = None) -> None:
+    if context.show_errors_tracebacks:
+        message = error.exception_with_traceback
+    else:
+        message = error.exception
+    if error.exception.startswith("InvalidSchema") and context.validate_schema:
+        message += DISABLE_SCHEMA_VALIDATION_MESSAGE + "\n"
+    click.secho(message, fg="red")
+    if error.example is not None:
+        display_example(context, error.example, seed=seed)
 
 
 def display_failures(context: ExecutionContext, event: events.Finished) -> None:
@@ -155,7 +163,7 @@ def display_failures(context: ExecutionContext, event: events.Finished) -> None:
 
 
 def display_failures_for_single_test(context: ExecutionContext, result: SerializedTestResult) -> None:
-    """Display a failure for a single method / endpoint."""
+    """Display a failure for a single method / path."""
     display_subsection(result)
     checks = get_unique_failures(result.checks)
     for idx, check in enumerate(checks, 1):
@@ -280,7 +288,7 @@ def display_internal_error(context: ExecutionContext, event: events.InternalErro
 
 def handle_initialized(context: ExecutionContext, event: events.Initialized) -> None:
     """Display information about the test session."""
-    context.endpoints_count = event.endpoints_count
+    context.operations_count = event.operations_count
     display_section_name("Schemathesis test session starts")
     versions = (
         f"platform {platform.system()} -- "
@@ -301,25 +309,32 @@ def handle_initialized(context: ExecutionContext, event: events.Initialized) ->
     click.echo(f"Base URL: {event.base_url}")
     click.echo(f"Specification version: {event.specification_name}")
     click.echo(f"Workers: {context.workers_num}")
-    click.secho(f"collected endpoints: {event.endpoints_count}", bold=True)
-    if event.endpoints_count >= 1:
+    click.secho(f"Collected API operations: {event.operations_count}", bold=True)
+    if event.operations_count >= 1:
         click.echo()
 
 
+TRUNCATION_PLACEHOLDER = "[...]"
+
+
 def handle_before_execution(context: ExecutionContext, event: events.BeforeExecution) -> None:
-    """Display what method / endpoint will be tested next."""
-    message = f"{event.method} {event.path} "
+    """Display what method / path will be tested next."""
+    # We should display execution result + percentage in the end. For example:
+    max_length = get_terminal_width() - len(" . [XXX%]") - len(TRUNCATION_PLACEHOLDER)
+    message = f"{event.method} {event.path}"
     if event.recursion_level > 0:
         message = f"{'    ' * event.recursion_level}-> {message}"
         # This value is not `None` - the value is set in runtime before this line
-        context.endpoints_count += 1  # type: ignore
+        context.operations_count += 1  # type: ignore
+
+    message = message[:max_length] + (message[max_length:] and "[...]") + " "
     context.current_line_length = len(message)
     click.echo(message, nl=False)
 
 
 def handle_after_execution(context: ExecutionContext, event: events.AfterExecution) -> None:
-    """Display the execution result + current progress at the same line with the method / endpoint names."""
-    context.endpoints_processed += 1
+    """Display the execution result + current progress at the same line with the method / path names."""
+    context.operations_processed += 1
     context.results.append(event.result)
     display_execution_result(context, event)
     display_percentage(context, event)
