@@ -31,11 +31,14 @@ def from_path(
     *,
     app: Any = None,
     validate_schema: bool = True,
-    skip_deprecated_endpoints: bool = False,
+    skip_deprecated_operations: bool = False,
     data_generation_methods: Iterable[DataGenerationMethod] = DEFAULT_DATA_GENERATION_METHODS,
     force_schema_version: Optional[str] = None,
 ) -> BaseOpenAPISchema:
-    """Load a file from OS path and parse to schema instance."""
+    """Load Open API schema via a file from an OS path.
+
+    :param path: A path to the schema file.
+    """
     with open(path) as fd:
         return from_file(
             fd,
@@ -47,7 +50,7 @@ def from_path(
             operation_id=operation_id,
             app=app,
             validate_schema=validate_schema,
-            skip_deprecated_endpoints=skip_deprecated_endpoints,
+            skip_deprecated_operations=skip_deprecated_operations,
             data_generation_methods=data_generation_methods,
             force_schema_version=force_schema_version,
         )
@@ -64,15 +67,16 @@ def from_uri(
     *,
     app: Any = None,
     validate_schema: bool = True,
-    skip_deprecated_endpoints: bool = False,
+    skip_deprecated_operations: bool = False,
     data_generation_methods: Iterable[DataGenerationMethod] = DEFAULT_DATA_GENERATION_METHODS,
     force_schema_version: Optional[str] = None,
     **kwargs: Any,
 ) -> BaseOpenAPISchema:
-    """Load a remote resource and parse to schema instance."""
-    headers = kwargs.setdefault("headers", {})
-    if "user-agent" not in {header.lower() for header in headers}:
-        kwargs["headers"]["User-Agent"] = USER_AGENT
+    """Load Open API schema from the network.
+
+    :param str uri: Schema URL.
+    """
+    _setup_headers(kwargs)
     if not base_url and port:
         base_url = str(URL(uri).with_port(port))
     response = requests.get(uri, **kwargs)
@@ -90,7 +94,7 @@ def from_uri(
         operation_id=operation_id,
         app=app,
         validate_schema=validate_schema,
-        skip_deprecated_endpoints=skip_deprecated_endpoints,
+        skip_deprecated_operations=skip_deprecated_operations,
         data_generation_methods=data_generation_methods,
         force_schema_version=force_schema_version,
     )
@@ -107,14 +111,14 @@ def from_file(
     *,
     app: Any = None,
     validate_schema: bool = True,
-    skip_deprecated_endpoints: bool = False,
+    skip_deprecated_operations: bool = False,
     data_generation_methods: Iterable[DataGenerationMethod] = DEFAULT_DATA_GENERATION_METHODS,
     force_schema_version: Optional[str] = None,
     **kwargs: Any,  # needed in the runner to have compatible API across all loaders
 ) -> BaseOpenAPISchema:
-    """Load a file content and parse to schema instance.
+    """Load Open API schema from a file descriptor, string or bytes.
 
-    `file` could be a file descriptor, string or bytes.
+    :param file: Could be a file descriptor, string or bytes.
     """
     raw = yaml.load(file, StringDatesYAMLLoader)
     return from_dict(
@@ -127,7 +131,7 @@ def from_file(
         operation_id=operation_id,
         app=app,
         validate_schema=validate_schema,
-        skip_deprecated_endpoints=skip_deprecated_endpoints,
+        skip_deprecated_operations=skip_deprecated_operations,
         data_generation_methods=data_generation_methods,
         force_schema_version=force_schema_version,
     )
@@ -144,15 +148,18 @@ def from_dict(
     *,
     app: Any = None,
     validate_schema: bool = True,
-    skip_deprecated_endpoints: bool = False,
+    skip_deprecated_operations: bool = False,
     data_generation_methods: Iterable[DataGenerationMethod] = DEFAULT_DATA_GENERATION_METHODS,
     force_schema_version: Optional[str] = None,
 ) -> BaseOpenAPISchema:
-    """Get a proper abstraction for the given raw schema."""
+    """Load Open API schema from a Python dictionary.
+
+    :param dict raw_schema: A schema to load.
+    """
     dispatch("before_load_schema", HookContext(), raw_schema)
 
     def init_openapi_2() -> SwaggerV20:
-        _maybe_validate_schema(raw_schema, definitions.SWAGGER_20, validate_schema)
+        _maybe_validate_schema(raw_schema, definitions.SWAGGER_20_VALIDATOR, validate_schema)
         return SwaggerV20(
             raw_schema,
             location=location,
@@ -163,12 +170,12 @@ def from_dict(
             operation_id=operation_id,
             app=app,
             validate_schema=validate_schema,
-            skip_deprecated_endpoints=skip_deprecated_endpoints,
+            skip_deprecated_operations=skip_deprecated_operations,
             data_generation_methods=data_generation_methods,
         )
 
     def init_openapi_3() -> OpenApi30:
-        _maybe_validate_schema(raw_schema, definitions.OPENAPI_30, validate_schema)
+        _maybe_validate_schema(raw_schema, definitions.OPENAPI_30_VALIDATOR, validate_schema)
         return OpenApi30(
             raw_schema,
             location=location,
@@ -179,7 +186,7 @@ def from_dict(
             operation_id=operation_id,
             app=app,
             validate_schema=validate_schema,
-            skip_deprecated_endpoints=skip_deprecated_endpoints,
+            skip_deprecated_operations=skip_deprecated_operations,
             data_generation_methods=data_generation_methods,
         )
 
@@ -194,10 +201,12 @@ def from_dict(
     raise ValueError("Unsupported schema type")
 
 
-def _maybe_validate_schema(instance: Dict[str, Any], schema: Dict[str, Any], validate_schema: bool) -> None:
+def _maybe_validate_schema(
+    instance: Dict[str, Any], validator: jsonschema.validators.Draft4Validator, validate_schema: bool
+) -> None:
     if validate_schema:
         try:
-            jsonschema.validate(instance, schema)
+            validator.validate(instance)
         except TypeError as exc:
             raise ValidationError("Invalid schema") from exc
 
@@ -209,10 +218,18 @@ def from_pytest_fixture(
     tag: Optional[Filter] = NOT_SET,
     operation_id: Optional[Filter] = NOT_SET,
     validate_schema: bool = True,
-    skip_deprecated_endpoints: bool = False,
+    skip_deprecated_operations: bool = False,
     data_generation_methods: Iterable[DataGenerationMethod] = DEFAULT_DATA_GENERATION_METHODS,
 ) -> LazySchema:
-    """Needed for a consistent library API."""
+    """Load schema from a ``pytest`` fixture.
+
+    It is useful if you don't want to make network requests during module loading. With this loader you can defer it
+    to a fixture.
+
+    Note, the fixture should return a ``BaseSchema`` instance loaded with another loader.
+
+    :param str fixture_name: The name of a fixture to load.
+    """
     return LazySchema(
         fixture_name,
         method=method,
@@ -220,7 +237,7 @@ def from_pytest_fixture(
         tag=tag,
         operation_id=operation_id,
         validate_schema=validate_schema,
-        skip_deprecated_endpoints=skip_deprecated_endpoints,
+        skip_deprecated_operations=skip_deprecated_operations,
         data_generation_methods=data_generation_methods,
     )
 
@@ -234,20 +251,20 @@ def from_wsgi(
     tag: Optional[Filter] = None,
     operation_id: Optional[Filter] = None,
     validate_schema: bool = True,
-    skip_deprecated_endpoints: bool = False,
+    skip_deprecated_operations: bool = False,
     data_generation_methods: Iterable[DataGenerationMethod] = DEFAULT_DATA_GENERATION_METHODS,
     force_schema_version: Optional[str] = None,
     **kwargs: Any,
 ) -> BaseOpenAPISchema:
-    headers = kwargs.setdefault("headers", {})
-    if "user-agent" not in {header.lower() for header in headers}:
-        kwargs["headers"]["User-Agent"] = USER_AGENT
+    """Load Open API schema from a WSGI app.
+
+    :param str schema_path: An in-app relative URL to the schema.
+    :param app: A WSGI app instance.
+    """
+    _setup_headers(kwargs)
     client = Client(app, WSGIResponse)
     response = client.get(schema_path, **kwargs)
-    # Raising exception to provide unified behavior
-    # E.g. it will be handled in CLI - a proper error message will be shown
-    if 400 <= response.status_code < 600:
-        raise HTTPError(response=response, url=schema_path)
+    check_response(response, schema_path)
     return from_file(
         response.data,
         location=schema_path,
@@ -258,7 +275,7 @@ def from_wsgi(
         operation_id=operation_id,
         app=app,
         validate_schema=validate_schema,
-        skip_deprecated_endpoints=skip_deprecated_endpoints,
+        skip_deprecated_operations=skip_deprecated_operations,
         data_generation_methods=data_generation_methods,
         force_schema_version=force_schema_version,
     )
@@ -282,11 +299,16 @@ def from_aiohttp(
     operation_id: Optional[Filter] = None,
     *,
     validate_schema: bool = True,
-    skip_deprecated_endpoints: bool = False,
+    skip_deprecated_operations: bool = False,
     data_generation_methods: Iterable[DataGenerationMethod] = DEFAULT_DATA_GENERATION_METHODS,
     force_schema_version: Optional[str] = None,
     **kwargs: Any,
 ) -> BaseOpenAPISchema:
+    """Load Open API schema from an AioHTTP app.
+
+    :param str schema_path: An in-app relative URL to the schema.
+    :param app: An AioHTTP app instance.
+    """
     from .extra._aiohttp import run_server  # pylint: disable=import-outside-toplevel
 
     port = run_server(app)
@@ -300,7 +322,7 @@ def from_aiohttp(
         tag=tag,
         operation_id=operation_id,
         validate_schema=validate_schema,
-        skip_deprecated_endpoints=skip_deprecated_endpoints,
+        skip_deprecated_operations=skip_deprecated_operations,
         data_generation_methods=data_generation_methods,
         force_schema_version=force_schema_version,
         **kwargs,
@@ -315,20 +337,20 @@ def from_asgi(
     endpoint: Optional[Filter] = None,
     tag: Optional[Filter] = None,
     validate_schema: bool = True,
-    skip_deprecated_endpoints: bool = False,
+    skip_deprecated_operations: bool = False,
     data_generation_methods: Iterable[DataGenerationMethod] = DEFAULT_DATA_GENERATION_METHODS,
     force_schema_version: Optional[str] = None,
     **kwargs: Any,
 ) -> BaseOpenAPISchema:
-    headers = kwargs.setdefault("headers", {})
-    if "user-agent" not in {header.lower() for header in headers}:
-        kwargs["headers"]["User-Agent"] = USER_AGENT
+    """Load Open API schema from an ASGI app.
+
+    :param str schema_path: An in-app relative URL to the schema.
+    :param app: An ASGI app instance.
+    """
+    _setup_headers(kwargs)
     client = ASGIClient(app)
     response = client.get(schema_path, **kwargs)
-    # Raising exception to provide unified behavior
-    # E.g. it will be handled in CLI - a proper error message will be shown
-    if 400 <= response.status_code < 600:
-        raise HTTPError(response=response, url=schema_path)
+    check_response(response, schema_path)
     return from_file(
         response.text,
         location=schema_path,
@@ -338,7 +360,20 @@ def from_asgi(
         tag=tag,
         app=app,
         validate_schema=validate_schema,
-        skip_deprecated_endpoints=skip_deprecated_endpoints,
+        skip_deprecated_operations=skip_deprecated_operations,
         data_generation_methods=data_generation_methods,
         force_schema_version=force_schema_version,
     )
+
+
+def check_response(response: requests.Response, schema_path: str) -> None:
+    # Raising exception to provide unified behavior
+    # E.g. it will be handled in CLI - a proper error message will be shown
+    if 400 <= response.status_code < 600:
+        raise HTTPError(response=response, url=schema_path)
+
+
+def _setup_headers(kwargs: Dict[str, Any]) -> None:
+    headers = kwargs.setdefault("headers", {})
+    if "user-agent" not in {header.lower() for header in headers}:
+        kwargs["headers"]["User-Agent"] = USER_AGENT
