@@ -7,14 +7,14 @@ from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, Uni
 import attr
 import hypothesis
 
-from ..._hypothesis import make_test_or_exception
+from ..._hypothesis import create_test
 from ...models import CheckFunction, TestResultSet
 from ...stateful import Feedback, Stateful
 from ...targets import Target
 from ...types import RawAuth
-from ...utils import capture_hypothesis_output, get_requests_auth
+from ...utils import Ok, capture_hypothesis_output, get_requests_auth
 from .. import events
-from .core import BaseRunner, asgi_test, get_session, network_test, run_test, wsgi_test
+from .core import BaseRunner, asgi_test, get_session, handle_schema_error, network_test, run_test, wsgi_test
 
 
 def _run_task(
@@ -33,10 +33,12 @@ def _run_task(
     def _run_tests(maker: Callable, recursion_level: int = 0) -> None:
         if recursion_level > stateful_recursion_limit:
             return
-        for _endpoint, data_generation_method, test in maker(test_template, settings, seed):
-            feedback = Feedback(stateful, _endpoint)
-            for event in run_test(
-                _endpoint,
+        for _result, _data_generation_method in maker(test_template, settings, seed):
+            # `result` is always `Ok` here
+            _operation, test = _result.ok()
+            feedback = Feedback(stateful, _operation)
+            for _event in run_test(
+                _operation,
                 test,
                 checks,
                 data_generation_method,
@@ -46,15 +48,31 @@ def _run_task(
                 feedback=feedback,
                 **kwargs,
             ):
-                events_queue.put(event)
+                events_queue.put(_event)
             _run_tests(feedback.get_stateful_tests, recursion_level + 1)
 
     with capture_hypothesis_output():
         while not tasks_queue.empty():
-            endpoint, data_generation_method = tasks_queue.get()
-            items = (endpoint, data_generation_method, make_test_or_exception(endpoint, test_template, settings, seed))
-            # This lambda ignores the input arguments to support the same interface for `feedback.get_stateful_tests`
-            _run_tests(lambda *_: (items,))
+            result, data_generation_method = tasks_queue.get()
+            if isinstance(result, Ok):
+                operation = result.ok()
+                test_function = create_test(
+                    operation=operation,
+                    test=test_template,
+                    settings=settings,
+                    seed=seed,
+                    data_generation_method=data_generation_method,
+                )
+                items = (
+                    Ok((operation, test_function)),
+                    data_generation_method,
+                )
+                # This lambda ignores the input arguments to support the same interface for
+                # `feedback.get_stateful_tests`
+                _run_tests(lambda *_: (items,))
+            else:
+                for event in handle_schema_error(result.err(), results, data_generation_method, 0):
+                    events_queue.put(event)
 
 
 def thread_task(
@@ -200,12 +218,12 @@ class ThreadPoolRunner(BaseRunner):
             yield events.Interrupted()
 
     def _get_tasks_queue(self) -> Queue:
-        """All endpoints are distributed among all workers via a queue."""
+        """All API operations are distributed among all workers via a queue."""
         tasks_queue: Queue = Queue()
         tasks_queue.queue.extend(
             [
-                (endpoint, data_generation_method)
-                for endpoint in self.schema.get_all_endpoints()
+                (operation, data_generation_method)
+                for operation in self.schema.get_all_operations()
                 for data_generation_method in self.schema.data_generation_methods
             ]
         )
@@ -245,6 +263,7 @@ class ThreadPoolRunner(BaseRunner):
                 "request_tls_verify": self.request_tls_verify,
                 "store_interactions": self.store_interactions,
                 "max_response_time": self.max_response_time,
+                "dry_run": self.dry_run,
             },
         }
 
@@ -270,6 +289,7 @@ class ThreadPoolWSGIRunner(ThreadPoolRunner):
                 "headers": self.headers,
                 "store_interactions": self.store_interactions,
                 "max_response_time": self.max_response_time,
+                "dry_run": self.dry_run,
             },
         }
 
@@ -293,6 +313,7 @@ class ThreadPoolASGIRunner(ThreadPoolRunner):
             "kwargs": {
                 "store_interactions": self.store_interactions,
                 "max_response_time": self.max_response_time,
+                "dry_run": self.dry_run,
             },
         }
 
