@@ -1,5 +1,5 @@
 from functools import partial
-from typing import Any, Callable, Dict, Generator, List, Optional, Tuple, cast
+from typing import Any, Dict, Generator, List, Optional, Tuple, cast
 from urllib.parse import urlsplit
 
 import attr
@@ -10,11 +10,11 @@ from hypothesis_graphql import strategies as gql_st
 
 from ... import DataGenerationMethod
 from ...checks import not_a_server_error
+from ...exceptions import InvalidSchema
 from ...hooks import HookDispatcher
-from ...models import Case, CheckFunction, Endpoint
+from ...models import APIOperation, Case, CheckFunction
 from ...schemas import BaseSchema
-from ...stateful import Feedback
-from ...utils import GenericResponse
+from ...utils import GenericResponse, Ok, Result
 
 
 @attr.s()  # pragma: no mutate
@@ -30,7 +30,7 @@ class GraphQLCase(Case):
         final_headers = self._get_headers(headers)
         return {
             "method": self.method,
-            "path": self.endpoint.schema.get_full_path(self.formatted_path),
+            "path": self.operation.schema.get_full_path(self.formatted_path),
             "headers": final_headers,
             "query_string": self.query,
             "json": {"query": self.body},
@@ -65,24 +65,22 @@ class GraphQLSchema(BaseSchema):
     def _get_base_path(self) -> str:
         return cast(str, urlsplit(self.location).path)
 
-    def get_all_endpoints(self) -> Generator[Endpoint, None, None]:
-        yield Endpoint(
-            base_url=self.location, path=self.base_path, method="POST", schema=self, definition=None  # type: ignore
+    def get_all_operations(self) -> Generator[Result[APIOperation, InvalidSchema], None, None]:
+        yield Ok(
+            APIOperation(
+                base_url=self.get_base_url(), path=self.base_path, method="POST", schema=self, definition=None  # type: ignore
+            )
         )
 
     def get_case_strategy(
         self,
-        endpoint: Endpoint,
+        operation: APIOperation,
         hooks: Optional[HookDispatcher] = None,
-        feedback: Optional[Feedback] = None,
         data_generation_method: DataGenerationMethod = DataGenerationMethod.default(),
     ) -> SearchStrategy:
-        constructor = partial(GraphQLCase, endpoint=endpoint)
+        constructor = partial(GraphQLCase, operation=operation)
         schema = graphql.build_client_schema(self.raw_schema)
         return st.builds(constructor, body=gql_st.query(schema))
 
-    def get_strategies_from_examples(self, endpoint: Endpoint) -> List[SearchStrategy[Case]]:
+    def get_strategies_from_examples(self, operation: APIOperation) -> List[SearchStrategy[Case]]:
         return []
-
-    def get_hypothesis_conversion(self, endpoint: Endpoint, location: str) -> Optional[Callable]:
-        return None
