@@ -13,17 +13,7 @@ def to_json_schema(schema: Dict[str, Any], nullable_name: str) -> Dict[str, Any]
     schema = deepcopy(schema)
     if schema.get(nullable_name) is True:
         del schema[nullable_name]
-        in_ = schema.get("in")
-        if in_ == "body":
-            schema["schema"] = {"anyOf": [schema["schema"], {"type": "null"}]}
-        elif in_:
-            initial_type = {"type": schema["type"]}
-            if schema.get("enum"):
-                initial_type["enum"] = schema.pop("enum")
-            schema["anyOf"] = [initial_type, {"type": "null"}]
-            del schema["type"]
-        else:
-            schema = {"anyOf": [schema, {"type": "null"}]}
+        schema = {"anyOf": [schema, {"type": "null"}]}
     if schema.get("type") == "file":
         schema["type"] = "string"
         schema["format"] = "binary"
