@@ -2,8 +2,8 @@ from typing import Any, Dict, List
 
 from hypothesis.strategies import SearchStrategy
 
-from ...models import Case, Endpoint
-from ._hypothesis import PARAMETERS, _get_case_strategy, prepare_strategy
+from ...models import APIOperation, Case
+from ._hypothesis import PARAMETERS, get_case_strategy
 from .constants import LOCATION_TO_CONTAINER
 
 
@@ -15,27 +15,32 @@ def get_object_example_from_properties(object_schema: Dict[str, Any]) -> Dict[st
     }
 
 
-def get_parameter_examples(endpoint_def: Dict[str, Any], examples_field: str) -> List[Dict[str, Any]]:
+def get_parameter_examples(operation_definition: Dict[str, Any], examples_field: str) -> List[Dict[str, Any]]:
     """Gets parameter examples from OAS3 `examples` keyword or `x-examples` for Swagger 2."""
     return [
         {
             "type": LOCATION_TO_CONTAINER.get(parameter["in"]),
             "name": parameter["name"],
-            "examples": [example["value"] for example in parameter[examples_field].values() if "value" in example],
+            "examples": [
+                example["value"]
+                for example in parameter[examples_field].values()
+                # IDEA: report when it is not a dictionary
+                if isinstance(example, dict) and "value" in example
+            ],
         }
-        for parameter in endpoint_def.get("parameters", [])
+        for parameter in operation_definition.get("parameters", [])
         if examples_field in parameter
     ]
 
 
-def get_parameter_example_from_properties(endpoint_def: Dict[str, Any]) -> Dict[str, Any]:
+def get_parameter_example_from_properties(operation_definition: Dict[str, Any]) -> Dict[str, Any]:
     static_parameters: Dict[str, Any] = {}
-    for parameter in endpoint_def.get("parameters", []):
+    for parameter in operation_definition.get("parameters", []):
         parameter_schema = parameter["schema"] if "schema" in parameter else parameter
         example = get_object_example_from_properties(parameter_schema)
         if example:
             parameter_type = LOCATION_TO_CONTAINER[parameter["in"]]
-            if parameter_type not in ("body", "form_data"):
+            if parameter_type != "body":
                 if parameter_type not in static_parameters:
                     static_parameters[parameter_type] = {}
                 static_parameters[parameter_type][parameter["name"]] = example
@@ -45,82 +50,74 @@ def get_parameter_example_from_properties(endpoint_def: Dict[str, Any]) -> Dict[
     return static_parameters
 
 
-def get_request_body_examples(endpoint_def: Dict[str, Any], examples_field: str) -> Dict[str, Any]:
+def get_request_body_examples(operation_definition: Dict[str, Any], examples_field: str) -> Dict[str, Any]:
     """Gets request body examples from OAS3 `examples` keyword or `x-examples` for Swagger 2."""
-    request_bodies_items = endpoint_def.get("requestBody", {}).get("content", {}).items()
+    # NOTE. `requestBody` is OAS3-specific. How should it work with OAS2?
+    request_bodies_items = operation_definition.get("requestBody", {}).get("content", {}).items()
     if not request_bodies_items:
         return {}
-    # first element in tuple in media type, second element is dict
-    media_type, schema = next(iter(request_bodies_items))
-    parameter_type = "body" if media_type != "multipart/form-data" else "form_data"
+    # first element in tuple is media type, second element is dict
+    _, schema = next(iter(request_bodies_items))
     return {
-        "type": parameter_type,
+        "type": "body",
         "examples": [example["value"] for example in schema.get(examples_field, {}).values() if "value" in example],
     }
 
 
-def get_request_body_example_from_properties(endpoint_def: Dict[str, Any]) -> Dict[str, Any]:
+def get_request_body_example_from_properties(operation_definition: Dict[str, Any]) -> Dict[str, Any]:
     static_parameters: Dict[str, Any] = {}
-    request_bodies_items = endpoint_def.get("requestBody", {}).get("content", {}).items()
+    request_bodies_items = operation_definition.get("requestBody", {}).get("content", {}).items()
     if request_bodies_items:
-        media_type, request_body_schema = next(iter(request_bodies_items))
+        _, request_body_schema = next(iter(request_bodies_items))
         example = get_object_example_from_properties(request_body_schema.get("schema", {}))
         if example:
-            request_body_type = "body" if media_type != "multipart/form-data" else "form_data"
-            static_parameters[request_body_type] = example
+            static_parameters["body"] = example
 
     return static_parameters
 
 
-def get_static_parameters_from_example(endpoint: Endpoint) -> Dict[str, Any]:
+def get_static_parameters_from_example(operation: APIOperation) -> Dict[str, Any]:
     static_parameters = {}
     for name in PARAMETERS:
-        parameter = getattr(endpoint, name)
-        if parameter is not None and "example" in parameter:
-            static_parameters[name] = parameter["example"]
+        parameters = getattr(operation, name)
+        example = parameters.example
+        if example:
+            static_parameters[name] = example
     return static_parameters
 
 
-def get_static_parameters_from_examples(endpoint: Endpoint, examples_field: str) -> List[Dict[str, Any]]:
+def get_static_parameters_from_examples(operation: APIOperation, examples_field: str) -> List[Dict[str, Any]]:
     """Get static parameters from OpenAPI examples keyword."""
-    endpoint_def = endpoint.definition.resolved
+    operation_definition = operation.definition.resolved
     return merge_examples(
-        get_parameter_examples(endpoint_def, examples_field), get_request_body_examples(endpoint_def, examples_field)
+        get_parameter_examples(operation_definition, examples_field),
+        get_request_body_examples(operation_definition, examples_field),
     )
 
 
-def get_static_parameters_from_properties(endpoint: Endpoint) -> Dict[str, Any]:
-    endpoint_def = endpoint.definition.resolved
+def get_static_parameters_from_properties(operation: APIOperation) -> Dict[str, Any]:
+    operation_definition = operation.definition.resolved
     return {
-        **get_parameter_example_from_properties(endpoint_def),
-        **get_request_body_example_from_properties(endpoint_def),
+        **get_parameter_example_from_properties(operation_definition),
+        **get_request_body_example_from_properties(operation_definition),
     }
 
 
-def get_strategies_from_examples(endpoint: Endpoint, examples_field: str = "examples") -> List[SearchStrategy[Case]]:
+def get_strategies_from_examples(
+    operation: APIOperation, examples_field: str = "examples"
+) -> List[SearchStrategy[Case]]:
     strategies = [
-        get_strategy(endpoint, static_parameters)
-        for static_parameters in get_static_parameters_from_examples(endpoint, examples_field)
+        get_case_strategy(operation=operation, **static_parameters)
+        for static_parameters in get_static_parameters_from_examples(operation, examples_field)
         if static_parameters
     ]
     for static_parameters in static_parameters_union(
-        get_static_parameters_from_example(endpoint), get_static_parameters_from_properties(endpoint)
+        get_static_parameters_from_example(operation), get_static_parameters_from_properties(operation)
     ):
-        strategies.append(get_strategy(endpoint, static_parameters))
+        strategies.append(get_case_strategy(operation=operation, **static_parameters))
     return strategies
 
 
-def get_strategy(endpoint: Endpoint, static_parameters: Dict[str, Any]) -> SearchStrategy[Case]:
-    strategies = {
-        parameter: prepare_strategy(
-            parameter, getattr(endpoint, parameter), endpoint.get_hypothesis_conversions(parameter)
-        )
-        for parameter in PARAMETERS - set(static_parameters)
-        if getattr(endpoint, parameter) is not None
-    }
-    return _get_case_strategy(endpoint, static_parameters, strategies)
-
-
 def merge_examples(
     parameter_examples: List[Dict[str, Any]], request_body_examples: Dict[str, Any]
 ) -> List[Dict[str, Any]]:
@@ -129,11 +126,8 @@ def merge_examples(
     for idx in range(num_examples(parameter_examples, request_body_examples)):
         static_parameters: Dict[str, Any] = {}
         for parameter in parameter_examples:
-            if parameter["type"] not in static_parameters:
-                static_parameters[parameter["type"]] = {}
-            static_parameters[parameter["type"]][parameter["name"]] = parameter["examples"][
-                min(idx, len(parameter["examples"]) - 1)
-            ]
+            container = static_parameters.setdefault(parameter["type"], {})
+            container[parameter["name"]] = parameter["examples"][min(idx, len(parameter["examples"]) - 1)]
         if "examples" in request_body_examples and request_body_examples["examples"]:
             static_parameters[request_body_examples["type"]] = request_body_examples["examples"][
                 min(idx, len(request_body_examples["examples"]) - 1)
@@ -158,9 +152,9 @@ def _static_parameters_union(base_obj: Dict[str, Any], fill_obj: Dict[str, Any])
     for parameter_type, examples in fill_obj.items():
         if parameter_type not in full_static_parameters:
             full_static_parameters[parameter_type] = examples
-        elif parameter_type not in ("body", "form_data"):
+        elif parameter_type != "body":
             # copy individual parameter names.
-            # body and form_data are unnamed, single examples, so we only do this for named parameters.
+            # body is unnamed, single examples, so we only do this for named parameters.
             for parameter_name, example in examples.items():
                 if parameter_name not in full_static_parameters[parameter_type]:
                     full_static_parameters[parameter_type][parameter_name] = example
