@@ -7,8 +7,8 @@ import jsonschema
 import requests
 import yaml
 
-from ...utils import StringDatesYAMLLoader, traverse_schema
-from .converter import to_json_schema
+from ...utils import StringDatesYAMLLoader
+from .converter import to_json_schema_recursive
 
 # Reference resolving will stop after this depth
 RECURSION_DEPTH_LIMIT = 100
@@ -38,24 +38,14 @@ def load_remote_uri(uri: str) -> Any:
     return yaml.load(response.content, StringDatesYAMLLoader)
 
 
-class ConvertingResolver(jsonschema.RefResolver):
-    """A custom resolver converts resolved OpenAPI schemas to JSON Schema.
+class InliningResolver(jsonschema.RefResolver):
+    """Inlines resolved schemas."""
 
-    When recursive schemas are validated we need to have resolved documents properly converted.
-    This approach is the simplest one, since this logic isolated in a single place.
-    """
-
-    def __init__(self, *args: Any, nullable_name: Any, **kwargs: Any) -> None:
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
         kwargs.setdefault(
             "handlers", {"file": load_file_uri, "": load_file, "http": load_remote_uri, "https": load_remote_uri}
         )
         super().__init__(*args, **kwargs)
-        self.nullable_name = nullable_name
-
-    def resolve(self, ref: str) -> Tuple[str, Any]:
-        url, document = super().resolve(ref)
-        document = traverse_schema(document, to_json_schema, nullable_name=self.nullable_name)
-        return url, document
 
     @overload  # pragma: no mutate
     def resolve_all(
@@ -73,15 +63,15 @@ class ConvertingResolver(jsonschema.RefResolver):
         if recursion_level > RECURSION_DEPTH_LIMIT:
             return item
         if isinstance(item, dict):
-            item = self.prepare(item)
-            if "$ref" in item and isinstance(item["$ref"], str):
-                with self.resolving(item["$ref"]) as resolved:
+            ref = item.get("$ref")
+            if ref is not None and isinstance(ref, str):
+                with self.resolving(ref) as resolved:
                     return self.resolve_all(resolved, recursion_level + 1)
+            item = deepcopy(item)
             for key, sub_item in item.items():
                 item[key] = self.resolve_all(sub_item, recursion_level)
         elif isinstance(item, list):
-            for idx, sub_item in enumerate(item):
-                item[idx] = self.resolve_all(sub_item, recursion_level)
+            item = [self.resolve_all(sub_item, recursion_level) for sub_item in deepcopy(item)]
         return item
 
     def resolve_in_scope(self, definition: Dict[str, Any], scope: str) -> Tuple[List[str], Dict[str, Any]]:
@@ -94,6 +84,19 @@ class ConvertingResolver(jsonschema.RefResolver):
             scopes.append(new_scope)
         return scopes, definition
 
-    def prepare(self, item: Dict[str, Any]) -> Dict[str, Any]:
-        """Parse schema extension, e.g. "x-nullable" field."""
-        return to_json_schema(item, self.nullable_name)
+
+class ConvertingResolver(InliningResolver):
+    """Convert resolved OpenAPI schemas to JSON Schema.
+
+    When recursive schemas are validated we need to have resolved documents properly converted.
+    This approach is the simplest one, since this logic isolated in a single place.
+    """
+
+    def __init__(self, *args: Any, nullable_name: Any, **kwargs: Any) -> None:
+        super().__init__(*args, **kwargs)
+        self.nullable_name = nullable_name
+
+    def resolve(self, ref: str) -> Tuple[str, Any]:
+        url, document = super().resolve(ref)
+        document = to_json_schema_recursive(document, nullable_name=self.nullable_name)
+        return url, document
