@@ -147,16 +147,15 @@ def _serialize_swagger2(definitions: DefinitionList) -> Generator[Optional[Calla
         if definition["in"] == "header":
             # Headers should be coerced to a string so we can check it for validity later
             yield to_string(name)
-        if definition["in"] != "body":
-            if type_ in ("array", "object"):
-                if collection_format == "csv":
-                    yield delimited(name, delimiter=",")
-                if collection_format == "ssv":
-                    yield delimited(name, delimiter=" ")
-                if collection_format == "tsv":
-                    yield delimited(name, delimiter="\t")
-                if collection_format == "pipes":
-                    yield delimited(name, delimiter="|")
+        if type_ in ("array", "object"):
+            if collection_format == "csv":
+                yield delimited(name, delimiter=",")
+            if collection_format == "ssv":
+                yield delimited(name, delimiter=" ")
+            if collection_format == "tsv":
+                yield delimited(name, delimiter="\t")
+            if collection_format == "pipes":
+                yield delimited(name, delimiter="|")
 
 
 serialize_openapi3_parameters = make_serializer(_serialize_openapi3)
@@ -175,8 +174,8 @@ def conversion(func: Callable[..., None]) -> Callable:
     return _wrapper
 
 
-def make_delimited(data: Dict[str, Any], delimiter: str = ",") -> str:
-    return delimiter.join(f"{key}={value}" for key, value in data.items())
+def make_delimited(data: Optional[Dict[str, Any]], delimiter: str = ",") -> str:
+    return delimiter.join(f"{key}={value}" for key, value in (data or {}).items())
 
 
 @conversion
@@ -187,7 +186,7 @@ def to_json(item: Generated, name: str) -> None:
 
 @conversion
 def delimited(item: Generated, name: str, delimiter: str) -> None:
-    item[name] = delimiter.join(map(str, item[name]))
+    item[name] = delimiter.join(map(str, item[name] or ()))
 
 
 @conversion
@@ -197,12 +196,15 @@ def deep_object(item: Generated, name: str) -> None:
     id={"role": "admin", "firstName": "Alex"} => id[role]=admin&id[firstName]=Alex
     """
     generated = item.pop(name)
-    item.update({f"{name}[{key}]": value for key, value in generated.items()})
+    if generated:
+        item.update({f"{name}[{key}]": value for key, value in generated.items()})
+    else:
+        item[name] = ""
 
 
 @conversion
 def comma_delimited_object(item: Generated, name: str) -> None:
-    item[name] = ",".join(map(str, sum(item[name].items(), ())))
+    item[name] = ",".join(map(str, sum((item[name] or {}).items(), ())))
 
 
 @conversion
@@ -214,7 +216,10 @@ def delimited_object(item: Generated, name: str) -> None:
 def extracted_object(item: Generated, name: str) -> None:
     """Merge a child node to the parent one."""
     generated = item.pop(name)
-    item.update(generated)
+    if generated:
+        item.update(generated)
+    else:
+        item[name] = ""
 
 
 @conversion
@@ -223,7 +228,11 @@ def label_primitive(item: Generated, name: str) -> None:
 
     5 => ".5"
     """
-    item[name] = f".{item[name]}"
+    new = item[name]
+    if new:
+        item[name] = f".{new}"
+    else:
+        item[name] = ""
 
 
 @conversion
@@ -242,7 +251,11 @@ def label_array(item: Generated, name: str, explode: Optional[bool]) -> None:
         delimiter = "."
     else:
         delimiter = ","
-    item[name] = f".{delimiter.join(map(str, item[name]))}"
+    new = delimiter.join(map(str, item[name] or ()))
+    if new:
+        item[name] = f".{new}"
+    else:
+        item[name] = ""
 
 
 @conversion
@@ -260,9 +273,12 @@ def label_object(item: Generated, name: str, explode: Optional[bool]) -> None:
     if explode:
         new = make_delimited(item[name], ".")
     else:
-        object_items = map(str, sum(item[name].items(), ()))
+        object_items = map(str, sum((item[name] or {}).items(), ()))
         new = ",".join(object_items)
-    item[name] = f".{new}"
+    if new:
+        item[name] = f".{new}"
+    else:
+        item[name] = new
 
 
 @conversion
@@ -271,7 +287,11 @@ def matrix_primitive(item: Generated, name: str) -> None:
 
     5 => ";id=5"
     """
-    item[name] = f";{name}={item[name]}"
+    new = item[name]
+    if new is not None:
+        item[name] = f";{name}={new}"
+    else:
+        item[name] = ""
 
 
 @conversion
@@ -287,10 +307,13 @@ def matrix_array(item: Generated, name: str, explode: Optional[bool]) -> None:
         id=[3, 4, 5] => ";id=3,4,5"
     """
     if explode:
-        new = ";".join(f"{name}={value}" for value in item[name])
+        new = ";".join(f"{name}={value}" for value in item[name] or ())
     else:
-        new = ",".join(map(str, item[name]))
-    item[name] = f";{new}"
+        new = ",".join(map(str, item[name] or ()))
+    if new:
+        item[name] = f";{new}"
+    else:
+        item[name] = new
 
 
 @conversion
@@ -308,9 +331,12 @@ def matrix_object(item: Generated, name: str, explode: Optional[bool]) -> None:
     if explode:
         new = make_delimited(item[name], ";")
     else:
-        object_items = map(str, sum(item[name].items(), ()))
+        object_items = map(str, sum((item[name] or {}).items(), ()))
         new = ",".join(object_items)
-    item[name] = f";{new}"
+    if new:
+        item[name] = f";{new}"
+    else:
+        item[name] = ""
 
 
 @conversion
